@@ -8,7 +8,18 @@ use Data::Dumper;
 
 use base 'Date::Holidays::Adapter';
 
-$VERSION = '1.29';
+$VERSION = '1.30';
+
+sub new {
+    my ( $class, %params ) = @_;
+
+    $params{countrycode} = 'USFederal';
+    $params{nocheck}     = 1;
+
+    my $self = $class->SUPER::new(%params);
+    return $self;
+}
+
 
 sub holidays {
     croak "holidays is unimplemented for ".__PACKAGE__;
@@ -30,13 +41,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Date::Holidays::Adapter::US - an adapter class for Date::Holidays::USFederal
 
 =head1 VERSION
 
-This POD describes version 1.25 of Date::Holidays::Adapter::US
+This POD describes version 1.30 of Date::Holidays::Adapter::US
 
 =head1 DESCRIPTION
 
@@ -87,12 +100,12 @@ Please refer to BUG REPORTING in L<Date::Holidays>
 
 =head1 AUTHOR
 
-Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
+Jonas Brømsø, (jonasbn) - C<< <jonasbn@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-L<Date::Holidays> and related modules are (C) by Jonas B. Nielsen, (jonasbn)
-2004-2020
+L<Date::Holidays> and related modules are (C) by Jonas Brømsø, (jonasbn)
+2004-2022
 
 Date-Holidays and related modules are released under the Artistic License 2.0
 
